#[non_exhaustive]pub enum KeyMatchStrength {
ByKeyId,
ByAlgorithm,
}Expand description
States how well a particular key matched the selection criteria from a JOSE header.
Used by both JWS verifiers and JWE ciphers to express the strength of a key match, allowing multi-key types to prefer exact matches over algorithm-only matches.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ByKeyId
Both the algorithm and the key ID match exactly.
ByAlgorithm
The algorithm matches but the key ID was not used for matching — either
the header has no kid, or this key has no kid registered.