pub enum CreateVerifierError {
UnsupportedKey,
MissingJwksUri,
Other {
source: BoxedError,
},
}Expand description
Errors that could occur while trying to create a verifier.
Variants
UnsupportedKey
The key is unsupported.
MissingJwksUri
No JWKS URI was provided to the verifier factory.
Other
Other kinds of errors that may occur while creating a verifier.
Fields

source: BoxedErrorThe underlying error.