JwtValidationError

Enum JwtValidationError 

pub enum JwtValidationError {
Show 16 variants Parse { source: JwsParseError, }, Signature { source: VerifyError, }, UnsignedToken, DisallowedAlgorithm { alg: String, }, UnrecognizedCriticalHeader { params: Vec<String>, }, Expired { expiration: SystemTime, now: SystemTime, }, NotYetValid { not_before: SystemTime, now: SystemTime, }, IssuedInFuture { issued_at: SystemTime, now: SystemTime, }, TokenTooOld { issued_at: SystemTime, max_token_age: Duration, }, InvalidTokenType { typ: Option<String>, }, ClaimMismatch { claim: &'static str, expected: String, actual: String, }, RequiredClaimMissing { claim: &'static str, }, JtiTooLong { len: usize, max_len: usize, }, JtiNotUnique, JtiCheck { source: Error, }, ExtraClaims { source: Error, },
}
Validation errors that can occur while processing a JWT.

Variants



Parse

The token could not be parsed as a compact JWS.

Fields

source: JwsParseError

The underlying error.



Signature

The token signature is invalid.

Fields

source: VerifyError

The underlying error.



UnsignedToken

The token is unsigned.



DisallowedAlgorithm

The token uses a disallowed signature algorithm.

Fields

alg: String

The algorithm used by the token.



UnrecognizedCriticalHeader

The token contains unrecognized critical header parameters.

Fields

params: Vec<String>

The unrecognized critical header parameters.



Expired

The token is expired.

Fields

expiration: SystemTime

The expiration timestamp of the JWT.

now: SystemTime

The current time.



NotYetValid

The token is not yet valid.

Fields

not_before: SystemTime

The not-before timestamp of the JWT.

now: SystemTime

The current time.



IssuedInFuture

The token is issued in the future.

Fields

issued_at: SystemTime

The issued-at timestamp of the JWT.

now: SystemTime

The current time.



TokenTooOld

The token is too old.

Fields

issued_at: SystemTime

The issued-at timestamp of the JWT.

max_token_age: Duration

The maximum age of the token.



InvalidTokenType

The token type claim is invalid.

Fields

typ: Option<String>

The type of the JWT.



ClaimMismatch

A claim did not match the expected value.

Fields

claim: &'static str

The claim name.

expected: String

The expected value.

actual: String

The actual value.



RequiredClaimMissing

A required claim is missing from the JWT.

Fields

claim: &'static str

The missing claim.



JtiTooLong

The jti claim exceeds the maximum allowed length.

Fields

len: usize

The length of the jti value in bytes.

max_len: usize

The maximum allowed length in bytes.



JtiNotUnique

The JTI was required to be unique, but was previously marked as seen.



JtiCheck

There was an internal failure when attempting to check for JTI uniqueness.

Fields

source: Error

The underlying error.



ExtraClaims

The token is structurally valid but does not contain the required extra claims.

Fields

source: Error

The underlying deserialization error.