MetricsHttpClient

Struct MetricsHttpClient 

pub struct MetricsHttpClient<C> { /* private fields */ }
Available on crate feature metrics only.
An HttpClient wrapper that records a huskarl.http.request counter for each request.

Wrap your HTTP client with this type to instrument all outbound requests made by the huskarl library — including JWKS fetches and token introspection calls.

Labels

LabelValuesDescription
hostrequest hostnameIdentifies the remote server
methodGET, POST, etc.HTTP method
outcomesuccess, errorWhether the request succeeded

outcome is success when the server returned a 2xx response, and error for connection failures or non-2xx responses.

Example

let client = MetricsHttpClient::builder().inner(inner).build();

Implementations

Source

impl<C> MetricsHttpClient<C>

pub fn builder() -> MetricsHttpClientBuilder<C>

Creates a new MetricsHttpClient.

Source

impl<C> MetricsHttpClient<C>

pub fn inner(&self) -> &C

Returns a reference to the inner client.

pub fn into_inner(self) -> C

Unwraps the inner client.